@@ -19,6 +19,18 @@ def serve(
 datasets = typer.Typer(short_help="The datasets management.")
 
 
+@datasets.command(short_help="Create a new dataset by uploading a directory.")
+def create(
+    name: str = typer.Argument(..., help="The name of the dataset to create."),
+    source: str = typer.Argument(..., help="The path to the directory to upload."),
+    description: str = typer.Option(None, help="The description of the dataset."),
+):
+    from mw_python_sdk import create_dataset
+
+    create_dataset(name, source, "", description)
+    return
+
+
 @datasets.command(short_help="Upload a file or directory to the dataset.")
 def upload(
     source: str = typer.Argument(
